@@ -6,7 +6,7 @@ var PORT = process.env.PORT || 27372
 
 var server = http.createServer(function(req, res) {
   if (req.url === '/') {
-    res.writeHead(200, {'content-type': 'text/html'});
+    res.writeHead(200, { 'content-type': 'text/html' })
     res.end(
       '<form action="/upload" enctype="multipart/form-data" method="post">'+
       '<input type="text" name="title"><br>'+
@@ -19,17 +19,17 @@ var server = http.createServer(function(req, res) {
 
     form.parse(req, function(err, fields, files) {
       if (err) {
-        res.writeHead(400, {'content-type': 'text/plain'});
-        res.end("invalid request: " + err.message);
+        res.writeHead(400, { 'content-type': 'text/plain' })
+        res.end('invalid request: ' + err.message)
         return;
       }
-      res.writeHead(200, {'content-type': 'text/plain'});
+      res.writeHead(200, { 'content-type': 'text/plain' })
       res.write('received fields:\n\n '+util.inspect(fields));
       res.write('\n\n');
       res.end('received files:\n\n '+util.inspect(files));
     });
   } else {
-    res.writeHead(404, {'content-type': 'text/plain'});
+    res.writeHead(404, { 'content-type': 'text/plain' })
     res.end('404');
   }
 });
