@@ -63,7 +63,7 @@ var standaloneTests = [
     }
   },
   {
-    name: "connection aborted closed",
+    name: 'connection aborted closed',
     fn: function(cb) {
       var socket;
       var server = http.createServer(function (req, res) {
@@ -108,7 +108,7 @@ var standaloneTests = [
     }
   },
   {
-    name: "connection aborted",
+    name: 'connection aborted',
     fn: function(cb) {
       var server = http.createServer(function (req, res) {
         var form = new multiparty.Form();
@@ -130,15 +130,56 @@ var standaloneTests = [
       }).listen(0, 'localhost', function () {
         var client = net.connect(server.address().port);
         client.write(
-          "POST / HTTP/1.1\r\n" +
-          "Content-Length: 70\r\n" +
-          "Content-Type: multipart/form-data; boundary=foo\r\n\r\n");
+          'POST / HTTP/1.1\r\n' +
+          'Content-Length: 70\r\n' +
+          'Content-Type: multipart/form-data; boundary=foo\r\n\r\n')
         client.end();
       });
     }
   },
   {
-    name: "content transfer encoding",
+    name: 'connection aborted after close does error',
+    fn: function (cb) {
+      var body =
+        '--foo\r\n' +
+        'Content-Disposition: form-data; name="file1"; filename="file1"\r\n' +
+        'Content-Type: application/octet-stream\r\n' +
+        '\r\nThis is the file\r\n' +
+        '--foo--\r\n'
+      var client = null
+      var error = null
+      var server = http.createServer(function (req, res) {
+        var form = new multiparty.Form()
+
+        form.on('close', function () {
+          client.destroy()
+          setTimeout(function () {
+            assert.ifError(error)
+            server.close(cb)
+          }, 100)
+        })
+
+        form.on('error', function (err) {
+          error = err
+        })
+
+        form.on('part', function (part) {
+          part.resume()
+        })
+
+        form.parse(req)
+      }).listen(0, 'localhost', function () {
+        client = net.connect(server.address().port)
+        client.write(
+          'POST / HTTP/1.1\r\n' +
+          'Content-Length: ' + Buffer.byteLength(body) + '\r\n' +
+          'Content-Type: multipart/form-data; boundary=foo\r\n\r\n' +
+          body)
+      });
+    }
+  },
+  {
+    name: 'content transfer encoding',
     fn: function(cb) {
       var server = http.createServer(function(req, res) {
         var form = new multiparty.Form();
@@ -189,9 +230,9 @@ var standaloneTests = [
     }
   },
   {
-    name: "emit order",
+    name: 'emit order',
     fn: function(cb) {
-      var bigFile = path.join(FIXTURE_PATH, "file", "pf1y5.png");
+      var bigFile = path.join(FIXTURE_PATH, 'file', 'pf1y5.png')
 
       var server = http.createServer(function(req, res) {
         assert.strictEqual(req.url, '/upload');
@@ -226,7 +267,7 @@ var standaloneTests = [
 
         form.on('close', function() {
           assert.strictEqual(fieldsInOrder.length, 0);
-          res.end("OK");
+          res.end('OK')
         });
 
         form.parse(req);
@@ -250,7 +291,7 @@ var standaloneTests = [
     }
   },
   {
-    name: "epilogue last chunk",
+    name: 'epilogue last chunk',
     fn: function(cb) {
       var server = http.createServer(function(req, res) {
         var form = new multiparty.Form();
@@ -295,7 +336,7 @@ var standaloneTests = [
     }
   },
   {
-    name: "error listen after parse",
+    name: 'error listen after parse',
     fn: function(cb) {
       var form = new multiparty.Form();
       var req = new stream.Readable();
@@ -315,7 +356,7 @@ var standaloneTests = [
     }
   },
   {
-    name: "error unpipe",
+    name: 'error unpipe',
     fn: function(cb) {
       var err = null;
       var form = new multiparty.Form();
@@ -348,25 +389,25 @@ var standaloneTests = [
         // verification that error event implies unpipe call
         assert.ok(err);
         assert.ok(unpiped, 'req was unpiped');
-        assert.equal(req._readableState.flowing, false, 'req not flowing');
-        assert.equal(req._readableState.pipesCount, 0, 'req has 0 pipes');
+
+        assert.ok(!isReadableStreamFlowing(req), 'req not flowing')
+        assert.equal(getReadableStreamPipeCount(req), 0, 'req has 0 pipes')
         cb();
       })
 
       form.parse(req)
-      assert.equal(req._readableState.flowing, true, 'req flowing');
-      assert.equal(req._readableState.pipesCount, 1, 'req has 1 pipe');
+
+      assert.ok(isReadableStreamFlowing(req), 'req flowing')
+      assert.equal(getReadableStreamPipeCount(req), 1, 'req has 1 pipe')
     }
   },
   {
-    name: "invalid",
+    name: 'invalid',
     fn: function(cb) {
       var server = http.createServer(function(req, resp) {
         var form = new multiparty.Form();
 
-        var errCount = 0;
         form.on('error', function(err) {
-          errCount += 1;
           resp.end();
         });
         form.on('file', function(name, file) {
@@ -396,13 +437,13 @@ var standaloneTests = [
     }
   },
   {
-    name: "issue 15",
+    name: 'issue 15',
     fn: function(cb) {
       var server = http.createServer(function(req, res) {
         assert.strictEqual(req.url, '/upload');
         assert.strictEqual(req.method, 'POST');
 
-        var form = new multiparty.Form({autoFields:true,autoFiles:true});
+        var form = new multiparty.Form({ autoFields: true, autoFiles: true })
 
         form.on('error', function(err) {
           console.log(err);
@@ -466,13 +507,13 @@ var standaloneTests = [
     }
   },
   {
-    name: "maxFields error",
+    name: 'maxFields error',
     fn: function(cb) {
       var client;
       var server = http.createServer(function (req, res) {
-        var form = new multiparty.Form({maxFields: 1});
+        var form = new multiparty.Form({ maxFields: 1 })
         form.on('aborted', function () {
-          throw new Error("did not expect aborted");
+          throw new Error('did not expect aborted')
         });
         var first = true;
         form.on('error', function (err) {
@@ -491,33 +532,33 @@ var standaloneTests = [
       server.listen(function() {
         client = net.connect(server.address().port);
 
-        client.write("POST /upload HTTP/1.1\r\n" +
-          "Content-Length: 728\r\n" +
-          "Content-Type: multipart/form-data; boundary=----WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n" +
-          "\r\n" +
-          "------WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n" +
-          "Content-Disposition: form-data; name=\"title\"\r\n" +
-          "\r\n" +
-          "foofoo" +
-          "\r\n" +
-          "------WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n" +
-          "Content-Disposition: form-data; name=\"upload\"; filename=\"blah1.txt\"\r\n" +
-          "Content-Type: text/plain\r\n" +
-          "\r\n" +
-          "hi1\r\n" +
-          "\r\n" +
-          "------WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n");
+        client.write('POST /upload HTTP/1.1\r\n' +
+          'Content-Length: 728\r\n' +
+          'Content-Type: multipart/form-data; boundary=----WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n' +
+          '\r\n' +
+          '------WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n' +
+          'Content-Disposition: form-data; name="title"\r\n' +
+          '\r\n' +
+          'foofoo' +
+          '\r\n' +
+          '------WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n' +
+          'Content-Disposition: form-data; name="upload"; filename="blah1.txt"\r\n' +
+          'Content-Type: text/plain\r\n' +
+          '\r\n' +
+          'hi1\r\n' +
+          '\r\n' +
+          '------WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n')
       });
     }
   },
   {
-    name: "maxFieldsSize error",
+    name: 'maxFieldsSize error',
     fn: function(cb) {
       var client;
       var server = http.createServer(function (req, res) {
-        var form = new multiparty.Form({maxFieldsSize: 8});
+        var form = new multiparty.Form({ maxFieldsSize: 8 })
         form.on('aborted', function () {
-          throw new Error("did not expect aborted");
+          throw new Error('did not expect aborted')
         });
         var first = true;
         form.on('error', function (err) {
@@ -537,26 +578,26 @@ var standaloneTests = [
       server.listen(function() {
         client = net.connect(server.address().port);
 
-        client.write("POST /upload HTTP/1.1\r\n" +
-          "Content-Length: 678\r\n" +
-          "Content-Type: multipart/form-data; boundary=----WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n" +
-          "\r\n" +
-          "------WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n" +
-          "Content-Disposition: form-data; name=\"title\"\r\n" +
-          "\r\n" +
-          "foofoo" +
-          "\r\n" +
-          "------WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n" +
-          "Content-Disposition: form-data; name=\"text\"\r\n" +
-          "\r\n" +
-          "hi1\r\n" +
-          "\r\n" +
-          "------WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n");
+        client.write('POST /upload HTTP/1.1\r\n' +
+          'Content-Length: 678\r\n' +
+          'Content-Type: multipart/form-data; boundary=----WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n' +
+          '\r\n' +
+          '------WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n' +
+          'Content-Disposition: form-data; name="title"\r\n' +
+          '\r\n' +
+          'foofoo' +
+          '\r\n' +
+          '------WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n' +
+          'Content-Disposition: form-data; name="text"\r\n' +
+          '\r\n' +
+          'hi1\r\n' +
+          '\r\n' +
+          '------WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n')
       });
     }
   },
   {
-    name: "issue 21",
+    name: 'issue 21',
     fn: function(cb) {
       var client;
       var server = http.createServer(function(req, res) {
@@ -570,18 +611,18 @@ var standaloneTests = [
           var nameCount = 0;
           var name;
           for (name in fields) {
-            assert.strictEqual(name, "title");
+            assert.strictEqual(name, 'title')
             nameCount += 1;
 
             var values = fields[name];
             assert.strictEqual(values.length, 1);
-            assert.strictEqual(values[0], "foofoo");
+            assert.strictEqual(values[0], 'foofoo')
           }
           assert.strictEqual(nameCount, 1);
 
           nameCount = 0;
           for (name in files) {
-            assert.strictEqual(name, "upload");
+            assert.strictEqual(name, 'upload')
             nameCount += 1;
 
             var filesList = files[name];
@@ -596,7 +637,7 @@ var standaloneTests = [
           server.close(cb);
 
           function assertAndUnlink(file){
-            assert.strictEqual(file.fieldName, "upload");
+            assert.strictEqual(file.fieldName, 'upload')
             fs.unlinkSync(file.path);
           }
         });
@@ -604,46 +645,46 @@ var standaloneTests = [
       server.listen(function() {
         client = net.connect(server.address().port);
 
-        client.write("POST /upload HTTP/1.1\r\n" +
-          "Content-Length: 726\r\n" +
-          "Content-Type: multipart/form-data; boundary=----WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n" +
-          "\r\n" +
-          "------WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n" +
-          "Content-Disposition: form-data; name=\"title\"\r\n" +
-          "\r\n" +
-          "foofoo" +
-          "\r\n" +
-          "------WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n" +
-          "Content-Disposition: form-data; name=\"upload\"; filename=\"blah1.txt\"\r\n" +
-          "Content-Type: text/plain\r\n" +
-          "\r\n" +
-          "hi1\r\n" +
-          "\r\n" +
-          "------WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n" +
-          "Content-Disposition: form-data; name=\"upload\"; filename=\"blah2.txt\"\r\n" +
-          "Content-Type: text/plain\r\n" +
-          "\r\n" +
-          "hi2\r\n" +
-          "\r\n" +
-          "------WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n" +
-          "Content-Disposition: form-data; name=\"upload\"; filename=\"blah3.txt\"\r\n" +
-          "Content-Type: text/plain\r\n" +
-          "\r\n" +
-          "hi3\r\n" +
-          "\r\n" +
-          "------WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n" +
-          "Content-Disposition: form-data; name=\"upload\"; filename=\"blah4.txt\"\r\n" +
-          "Content-Type: text/plain\r\n" +
-          "\r\n" +
-          "hi4\r\n" +
-          "\r\n" +
-          "------WebKitFormBoundaryvfUZhxgsZDO7FXLF--\r\n"
+        client.write('POST /upload HTTP/1.1\r\n' +
+          'Content-Length: 726\r\n' +
+          'Content-Type: multipart/form-data; boundary=----WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n' +
+          '\r\n' +
+          '------WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n' +
+          'Content-Disposition: form-data; name="title"\r\n' +
+          '\r\n' +
+          'foofoo' +
+          '\r\n' +
+          '------WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n' +
+          'Content-Disposition: form-data; name="upload"; filename="blah1.txt"\r\n' +
+          'Content-Type: text/plain\r\n' +
+          '\r\n' +
+          'hi1\r\n' +
+          '\r\n' +
+          '------WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n' +
+          'Content-Disposition: form-data; name="upload"; filename="blah2.txt"\r\n' +
+          'Content-Type: text/plain\r\n' +
+          '\r\n' +
+          'hi2\r\n' +
+          '\r\n' +
+          '------WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n' +
+          'Content-Disposition: form-data; name="upload"; filename="blah3.txt"\r\n' +
+          'Content-Type: text/plain\r\n' +
+          '\r\n' +
+          'hi3\r\n' +
+          '\r\n' +
+          '------WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n' +
+          'Content-Disposition: form-data; name="upload"; filename="blah4.txt"\r\n' +
+          'Content-Type: text/plain\r\n' +
+          '\r\n' +
+          'hi4\r\n' +
+          '\r\n' +
+          '------WebKitFormBoundaryvfUZhxgsZDO7FXLF--\r\n'
         );
       });
     }
   },
   {
-    name: "issue 32",
+    name: 'issue 32',
     fn: function(cb) {
       var client;
       var server = http.createServer(function(req, res) {
@@ -654,7 +695,7 @@ var standaloneTests = [
             console.error(err.stack);
             return;
           }
-          assert.strictEqual(files.image[0].originalFilename, "测试文档")
+          assert.strictEqual(files.image[0].originalFilename, '测试文档')
           fs.unlinkSync(files.image[0].path);
           res.end();
           client.end();
@@ -665,22 +706,22 @@ var standaloneTests = [
         client = net.connect(server.address().port);
 
         client.write(
-          "POST /upload HTTP/1.1\r\n" +
-          "Accept: */*\r\n" +
-          "Content-Type: multipart/form-data; boundary=\"893e5556-f402-4fec-8180-c59333354c6f\"\r\n" +
-          "Content-Length: 187\r\n" +
-          "\r\n" +
-          "--893e5556-f402-4fec-8180-c59333354c6f\r\n" +
+          'POST /upload HTTP/1.1\r\n' +
+          'Accept: */*\r\n' +
+          'Content-Type: multipart/form-data; boundary="893e5556-f402-4fec-8180-c59333354c6f"\r\n' +
+          'Content-Length: 187\r\n' +
+          '\r\n' +
+          '--893e5556-f402-4fec-8180-c59333354c6f\r\n' +
           "Content-Disposition: form-data; name=\"image\"; filename*=utf-8''%E6%B5%8B%E8%AF%95%E6%96%87%E6%A1%A3\r\n" +
-          "\r\n" +
-          "\r\n" +
-          "--893e5556-f402-4fec-8180-c59333354c6f--\r\n"
+          '\r\n' +
+          '\r\n' +
+          '--893e5556-f402-4fec-8180-c59333354c6f--\r\n'
         );
       });
     }
   },
   {
-    name: "issue 36",
+    name: 'issue 36',
     fn: function(cb) {
       var server = http.createServer(function(req, res) {
         var form = new multiparty.Form();
@@ -716,13 +757,13 @@ var standaloneTests = [
     }
   },
   {
-    name: "issue 4",
+    name: 'issue 4',
     fn: function(cb) {
       var server = http.createServer(function(req, res) {
         assert.strictEqual(req.url, '/upload');
         assert.strictEqual(req.method, 'POST');
 
-        var form = new multiparty.Form({autoFields:true,autoFiles:true});
+        var form = new multiparty.Form({ autoFields: true, autoFiles: true })
 
         form.on('error', function(err) {
           console.log(err);
@@ -763,13 +804,13 @@ var standaloneTests = [
     }
   },
   {
-    name: "max fields",
+    name: 'max fields',
     fn: function(cb) {
       var server = http.createServer(function(req, res) {
         assert.strictEqual(req.url, '/upload');
         assert.strictEqual(req.method, 'POST');
 
-        var form = new multiparty.Form({autoFiles:true,maxFields:2});
+        var form = new multiparty.Form({ autoFiles: true, maxFields: 2 })
 
         var first = true;
         form.on('error', function (err) {
@@ -810,13 +851,13 @@ var standaloneTests = [
     }
   },
   {
-    name: "max files size exact",
+    name: 'max files size exact',
     fn: function(cb) {
       var server = http.createServer(function(req, res) {
         assert.strictEqual(req.url, '/upload');
         assert.strictEqual(req.method, 'POST');
 
-        var form = new multiparty.Form({autoFiles:true,maxFilesSize:768323}); // exact size of pf1y5.png
+        var form = new multiparty.Form({ autoFiles: true, maxFilesSize: 768323 }) // exact size of pf1y5.png
 
         var fileCount = 0;
         form.on('file', function(name, file) {
@@ -850,13 +891,13 @@ var standaloneTests = [
     }
   },
   {
-    name: "max files size",
+    name: 'max files size',
     fn: function(cb) {
       var server = http.createServer(function(req, res) {
         assert.strictEqual(req.url, '/upload');
         assert.strictEqual(req.method, 'POST');
 
-        var form = new multiparty.Form({autoFiles:true,maxFilesSize:800*1024});
+        var form = new multiparty.Form({ autoFiles: true, maxFilesSize: 800 * 1024 })
 
         var first = true;
         form.on('error', function (err) {
@@ -899,7 +940,59 @@ var standaloneTests = [
     }
   },
   {
-    name: "missing boundary end",
+    name: 'max files size edge',
+    fn: function(cb) {
+      var server = http.createServer(function(req, res) {
+        assert.strictEqual(req.url, '/upload');
+        assert.strictEqual(req.method, 'POST');
+
+        var form = new multiparty.Form({
+          autoFiles: true,
+          maxFilesSize: (768323 * 2) - 1 // exact size of 2 x pf1y5.png - 1
+        });
+
+        var first = true;
+        form.on('error', function (err) {
+          assert.ok(first);
+          first = false;
+          assert.strictEqual(err.code, 'ETOOBIG');
+          assert.strictEqual(err.status, 413);
+        });
+
+        var fileCount = 0;
+        form.on('file', function(name, file) {
+          fileCount += 1;
+          fs.unlinkSync(file.path);
+        });
+
+        form.parse(req, function(err, fields, files) {
+          assert.ok(fileCount <= 2);
+          res.statusCode = 413;
+          res.end('files too large');
+        });
+      });
+      server.listen(function() {
+        var url = 'http://localhost:' + server.address().port + '/upload';
+        var req = superagent.post(url);
+        req.attach('file0', fixture('pf1y5.png'), 'SOG1.JPG');
+        req.attach('file1', fixture('pf1y5.png'), 'SOG1.JPG');
+        req.on('error', function(err) {
+          assert.ifError(err);
+        });
+        req.end();
+        req.on('response', function(res) {
+          assert.equal(res.statusCode, 413);
+          server.close(cb);
+        });
+      });
+
+      function fixture(name) {
+        return path.join(FIXTURE_PATH, 'file', name)
+      }
+    }
+  },
+  {
+    name: 'missing boundary end',
     fn: function(cb) {
       var server = http.createServer(function(req, resp) {
         var form = new multiparty.Form();
@@ -946,7 +1039,7 @@ var standaloneTests = [
     }
   },
   {
-    name: "missing content-type error",
+    name: 'missing content-type error',
     fn: function(cb) {
       var server = http.createServer(function(req, res) {
         assert.strictEqual(req.url, '/upload');
@@ -977,7 +1070,7 @@ var standaloneTests = [
     }
   },
   {
-    name: "unsupported content-type error",
+    name: 'unsupported content-type error',
     fn: function(cb) {
       var server = http.createServer(function(req, res) {
         assert.strictEqual(req.url, '/upload');
@@ -1010,7 +1103,7 @@ var standaloneTests = [
     }
   },
   {
-    name: "content-type missing boundary error",
+    name: 'content-type missing boundary error',
     fn: function(cb) {
       var server = http.createServer(function(req, res) {
         assert.strictEqual(req.url, '/upload');
@@ -1047,7 +1140,7 @@ var standaloneTests = [
     }
   },
   {
-    name: "empty header field error",
+    name: 'empty header field error',
     fn: function(cb) {
       var server = http.createServer(function(req, resp) {
         var form = new multiparty.Form();
@@ -1062,6 +1155,7 @@ var standaloneTests = [
           assert.ok(err);
           assert.equal(err.message, 'Empty header field');
           assert.equal(err.statusCode, 400);
+          assert.equal(partCount, 0);
           server.close(cb);
         });
         form.on('close', function() {
@@ -1093,7 +1187,7 @@ var standaloneTests = [
     }
   },
   {
-    name: "request encoding",
+    name: 'request encoding',
     fn: function(cb) {
       var server = http.createServer(function(req, res) {
         assert.strictEqual(req.url, '/upload');
@@ -1131,7 +1225,7 @@ var standaloneTests = [
     }
   },
   {
-    name: "stream error",
+    name: 'stream error',
     fn: function(cb) {
       var server = http.createServer(function (req, res) {
         var form = new multiparty.Form();
@@ -1153,21 +1247,21 @@ var standaloneTests = [
       }).listen(0, 'localhost', function () {
         var client = net.connect(server.address().port);
         client.write(
-          "POST / HTTP/1.1\r\n" +
-          "Content-Length: 186\r\n" +
-          "Content-Type: multipart/form-data; boundary=--WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n" +
-          "\r\n" +
-          "----WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n" +
-          "Content-Disposition: form-data; name=\"upload\"; filename=\"blah1.txt\"\r\n" +
-          "Content-Type: plain/text\r\n" +
-          "\r\n" +
-          "hi1\r\n");
+          'POST / HTTP/1.1\r\n' +
+          'Content-Length: 186\r\n' +
+          'Content-Type: multipart/form-data; boundary=--WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n' +
+          '\r\n' +
+          '----WebKitFormBoundaryvfUZhxgsZDO7FXLF\r\n' +
+          'Content-Disposition: form-data; name="upload"; filename="blah1.txt"\r\n' +
+          'Content-Type: plain/text\r\n' +
+          '\r\n' +
+          'hi1\r\n')
         client.end();
       });
     }
   },
   {
-    name: "queued part error",
+    name: 'queued part error',
     fn: function(cb) {
       var server = http.createServer(function (req, res) {
         var form = new multiparty.Form();
@@ -1210,24 +1304,24 @@ var standaloneTests = [
       }).listen(0, 'localhost', function () {
         var client = net.connect(server.address().port);
         client.end(
-          "POST / HTTP/1.1\r\n" +
-          "Content-Length: 174\r\n" +
-          "Content-Type: multipart/form-data; boundary=--bounds\r\n" +
-          "\r\n" +
-          "----bounds\r\n" +
-          "Content-Disposition: form-data; name=\"key\"\r\n" +
-          "\r\n" +
-          "hi\r\n" +
-          "----bounds\r\n" +
-          "Content-Disposition: form-data; name=\"upload\"; filename=\"blah1.txt\"\r\n" +
-          "Content-Type: plain/text\r\n" +
-          "\r\n" +
-          "bye");
+          'POST / HTTP/1.1\r\n' +
+          'Content-Length: 174\r\n' +
+          'Content-Type: multipart/form-data; boundary=--bounds\r\n' +
+          '\r\n' +
+          '----bounds\r\n' +
+          'Content-Disposition: form-data; name="key"\r\n' +
+          '\r\n' +
+          'hi\r\n' +
+          '----bounds\r\n' +
+          'Content-Disposition: form-data; name="upload"; filename="blah1.txt"\r\n' +
+          'Content-Type: plain/text\r\n' +
+          '\r\n' +
+          'bye')
       });
     }
   },
   {
-    name: "issue 198",
+    name: 'issue 198',
     fn: function(cb) {
       var client;
       var server = http.createServer(function(req, res) {
@@ -1238,8 +1332,8 @@ var standaloneTests = [
             console.error(err.stack);
             return;
           }
-          assert.strictEqual(path.extname(files.image[0].path), ".y");
-          assert.strictEqual(files.image[0].originalFilename, "x.y\u2028%24(echo subshell)");
+          assert.strictEqual(path.extname(files.image[0].path), '.y')
+          assert.strictEqual(files.image[0].originalFilename, 'x.y\u2028%24(echo subshell)')
           fs.unlinkSync(files.image[0].path);
           res.end();
           client.end();
@@ -1250,16 +1344,16 @@ var standaloneTests = [
         client = net.connect(server.address().port);
 
         client.write(
-          "POST /upload HTTP/1.1\r\n" +
-          "Accept: */*\r\n" +
-          "Content-Type: multipart/form-data; boundary=\"893e5556-f402-4fec-8180-c59333354c6f\"\r\n" +
-          "Content-Length: 217\r\n" +
-          "\r\n" +
-          "--893e5556-f402-4fec-8180-c59333354c6f\r\n" +
+          'POST /upload HTTP/1.1\r\n' +
+          'Accept: */*\r\n' +
+          'Content-Type: multipart/form-data; boundary="893e5556-f402-4fec-8180-c59333354c6f"\r\n' +
+          'Content-Length: 217\r\n' +
+          '\r\n' +
+          '--893e5556-f402-4fec-8180-c59333354c6f\r\n' +
           "Content-Disposition: form-data; name=\"image\"; filename*=utf-8''%78%2E%79%E2%80%A8%24%28%65%63%68%6F%20%73%75%62%73%68%65%6C%6C%29\r\n" +
-          "\r\n" +
-          "\r\n" +
-          "--893e5556-f402-4fec-8180-c59333354c6f--\r\n"
+          '\r\n' +
+          '\r\n' +
+          '--893e5556-f402-4fec-8180-c59333354c6f--\r\n'
         );
       });
     }
@@ -1341,6 +1435,18 @@ function computeSha1(o) {
   };
 }
 
+function getReadableStreamPipeCount (stream) {
+  var count = stream._readableState.pipesCount
+
+  return typeof count !== 'number'
+    ? stream._readableState.pipes.length
+    : count
+}
+
+function isReadableStreamFlowing (stream) {
+  return Boolean(stream._readableState.flowing)
+}
+
 function uploadFixture(server, path, cb) {
   server.once('request', function(req, res) {
     var done = false
@@ -1354,12 +1460,12 @@ function uploadFixture(server, path, cb) {
 
     form.on('error', callback);
     form.on('file', function(name, value) {
-      var o = {type: 'file', name: name, value: value};
+      var o = { type: 'file', name: name, value: value }
       parts.push(o);
       pend.go(computeSha1(o));
     });
     form.on('field', function(name, value) {
-      parts.push({type: 'field', name: name, value: value});
+      parts.push({ type: 'field', name: name, value: value })
     });
     form.on('close', function() {
       res.end('OK');
@@ -1381,7 +1487,7 @@ function uploadFixture(server, path, cb) {
   var socket = net.createConnection(port)
   var file = fs.createReadStream(path)
 
-  file.pipe(socket, {end: false});
+  file.pipe(socket, { end: false })
   socket.on('data', function () {
     socket.end();
   });
